API docs for “spamfighter.rules.log”

# Module s.r.log

Part of spamfighter.rules View Source

Правила, управляющие логом сообщений.

Function | messageLogPut | Поместить сообщение в лог сообщений.

def messageLogPut(domain, message, log='messageLog', tag=None): (source)
Поместить сообщение в лог сообщений.

Дополнительно можно при помещении в лог указать дополнительный тэг, который будет сохранен в логе вместе с сообщением.

Parameters | domain | домен, относительно которого идёт анализ (type: `IDomain` )
| message | сообщение (type: `spamfighter.interfaces.IMessage` )
| log | имя свойства домена, содержащего лог сообщений (type: `str` )
| tag | дополнительный тэг, записываемый в лог (type: `str` )